==> haskell-openssl-streams-1.2.1.3-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.1.3
id: openssl-streams-1.2.1.3-I8ygaR9teJudzOXKGmlbF
key: openssl-streams-1.2.1.3-I8ygaR9teJudzOXKGmlbF
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: 52efe36f0dd4bbdf2c76f919f2824c82
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.6.2/site-local/openssl-streams-1.2.1.3
library-dirs: /usr/lib/ghc-8.6.2/site-local/openssl-streams-1.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/openssl-streams-1.2.1.3
hs-libraries: HSopenssl-streams-1.2.1.3-I8ygaR9teJudzOXKGmlbF
depends:
    HsOpenSSL-0.11.4.15-HtXpkfzA1nODGmxt96PiAW base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.0.1-7oJHkzP57f88H6M84jYHTU
    network-2.7.0.2-2fEEs0vTvHq3lWAStilHpJ
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openssl-streams-1.2.1.3-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openssl-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openssl-streams
version: 1.2.1.3
id: openssl-streams-1.2.1.3-IOOFIdQfNGF72vd8rysfrB
key: openssl-streams-1.2.1.3-IOOFIdQfNGF72vd8rysfrB
license: BSD-3-Clause
maintainer: Gregory Collins <greg@gregorycollins.net>
synopsis: OpenSSL network support for io-streams.
description:
    The openssl-streams library contains io-streams routines for secure
    networking using OpenSSL (by way of HsOpenSSL).
category: Network, IO-Streams
abi: 4745dcbb14943a049a3d527c0d2c4279
exposed: True
exposed-modules:
    System.IO.Streams.SSL
import-dirs: /usr/lib/ghc-8.6.3/site-local/openssl-streams-1.2.1.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/openssl-streams-1.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/openssl-streams-1.2.1.3
hs-libraries: HSopenssl-streams-1.2.1.3-IOOFIdQfNGF72vd8rysfrB
depends:
    HsOpenSSL-0.11.4.15-CQ2J7qnzJMI5whbcUUtFqY base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.0.1-HtnK8bnjFlpgXb0YwqMOU
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR
haddock-interfaces: /usr/share/doc/haskell-openssl-streams/html/openssl-streams.haddock
haddock-html: /usr/share/doc/haskell-openssl-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
